Subject: Re: bug#40001: tex-start-options-string not updated in texinfo.el

From: "Ernest N. Mamikonyan" <[email-masked]>
Date: Fri, 13 Mar 2020 10:37:17 -0400

On Fri, Mar 13 2020, Eli Zaretskii wrote:

>> From: "Ernest N. Mamikonyan" <[email-masked]>
>> Date: Mon, 09 Mar 2020 13:26:44 -0400
>> 
>> It seems that 'tex-start-options-string' was not updated to
>> 'tex-start-options' in texinfo.el after the change in version 22.
>> 
>> diff --git a/lisp/textmodes/texinfo.el b/lisp/textmodes/texinfo.el
>> index 438cb7798a..3898a3ba04 100644
>> --- a/lisp/textmodes/texinfo.el
>> +++ b/lisp/textmodes/texinfo.el
>> @@ -1002,9 +1002,9 @@ texinfo-tex-buffer
>>    (interactive)
>>    (require 'tex-mode)
>>    (let ((tex-command texinfo-texi2dvi-command)
>> -	;; Disable tex-start-options-string.  texi2dvi would not
>> -	;; understand anything specified here.
>> -	(tex-start-options-string ""))
>> +	;; Disable tex-start-options.  texi2dvi would not understand
>> +	;; anything specified here.
>> +	(tex-start-options ""))
>>      (tex-buffer)))
>
> Should we also bind tex-start-commands to some value (an empty
> string)?  If not, why not?

Yes, you're right. Since texi2dvi doesn't take initial commands like
TeX, why not get rid of tex-start-commands but allow the user to supply
command-line options:

diff --git a/lisp/textmodes/texinfo.el b/lisp/textmodes/texinfo.el
index 438cb7798a..a687a27e36 100644
--- a/lisp/textmodes/texinfo.el
+++ b/lisp/textmodes/texinfo.el
@@ -958,6 +958,11 @@ texinfo-texi2dvi-command
   :type 'string
   :group 'texinfo)
 
+(defcustom texinfo-texi2dvi-options ""
+  "Command line options for `texinfo-texi2dvi-command'."
+  :type 'string
+  :group 'texinfo)
+
 (defcustom texinfo-tex-command "tex"
   "Command used by `texinfo-tex-region' to run TeX on a region."
   :type 'string
@@ -1002,9 +1007,10 @@ texinfo-tex-buffer
   (interactive)
   (require 'tex-mode)
   (let ((tex-command texinfo-texi2dvi-command)
-	;; Disable tex-start-options-string.  texi2dvi would not
-	;; understand anything specified here.
-	(tex-start-options-string ""))
+	(tex-start-options texinfo-texi2dvi-options)
+	;; Disable tex-start-commands.  texi2dvi would not understand
+	;; anything specified here.
+        (tex-start-commands ""))
     (tex-buffer)))
 
 (defun texinfo-texindex ()

-- 
Ernie